@@ -34,7 +34,7 @@ from .attrdict import AttrDict
 class MILC(object):
     """MILC - An Opinionated Batteries Included Framework
     """
-    def __init__(self):
+    def __init__(self, version='unknown'):
         """Initialize the MILC object.
 
             version
@@ -55,7 +55,7 @@ class MILC(object):
         self.config = self.config_source = None
         self.config_file = None
         self.default_arguments = {}
-        self.version = 'unknown'
+        self.version = version
         self.platform = platform()
 
         # Figure out our program name
@@ -249,15 +249,13 @@ class MILC(object):
     def find_config_file(self):
         """Locate the config file.
         """
-        if self.config_file:
-            return self.config_file
-
         if '--config-file' in sys.argv:
             return Path(sys.argv[sys.argv.index('--config-file') + 1]).expanduser().resolve()
 
         filedir = user_config_dir(appname=self.prog_name, appauthor=os.environ.get('MILC_APP_AUTHOR', self.prog_name.upper()))
         filename = '%s.ini' % self.prog_name
-        return Path(filedir) / filename
+
+        return Path(filedir, filename).resolve()
 
     def argument(self, *args, **kwargs):
         """Decorator to call self.add_argument or self.<subcommand>.add_argument.
@@ -324,9 +322,9 @@ class MILC(object):
                     value = raw_config.get(section, option)
 
                     # Coerce values into useful datatypes
-                    if value.lower() in ['1', 'yes', 'true', 'on']:
+                    if value.lower() in ['yes', 'true', 'on']:
                         value = True
-                    elif value.lower() in ['0', 'no', 'false', 'off']:
+                    elif value.lower() in ['no', 'false', 'off']:
                         value = False
                     elif value.lower() in ['none']:
                         continue
@@ -375,14 +373,20 @@ class MILC(object):
             if argument not in self.arg_only or section not in self.arg_only[argument]:
                 # Determine the arg value and source
                 arg_value = getattr(self.args, argument)
+                passed_on_cmdline = False
+
+                if section in self.subcommands:
+                    default_value = self.subcommands[section].get_default(argument)
+                else:
+                    default_value = self._arg_parser.get_default(argument)
+
                 if argument in self._config_store_true and arg_value:
                     passed_on_cmdline = True
                 elif argument in self._config_store_false and not arg_value:
                     passed_on_cmdline = True
                 elif arg_value is not None:
-                    passed_on_cmdline = True
-                else:
-                    passed_on_cmdline = False
+                    if self.config[section][argument] is None or arg_value != default_value:
+                        passed_on_cmdline = True
 
                 # Merge this argument into self.config
                 if passed_on_cmdline and (argument in self.default_arguments['general'] or argument in self.default_arguments[entrypoint_name] or argument not in self.config[entrypoint_name]):
